==> virtual-additions-4.0.0%2B1.21.9-sources.jar: com/github/suninvr/virtualadditions/item/ProjectionSpyglassItem.java <==
package com.github.suninvr.virtualadditions.item;

import com.github.suninvr.virtualadditions.entity.PlayerProjectionEntity;
import com.github.suninvr.virtualadditions.registry.VAItems;
import com.github.suninvr.virtualadditions.registry.VASoundEvents;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3468;
import net.minecraft.class_5328;
import net.minecraft.class_5538;
import org.jetbrains.annotations.Nullable;

public class ProjectionSpyglassItem extends class_5538 {
    public ProjectionSpyglassItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public int method_7881(class_1799 stack, class_1309 user) {
        return 12000;
    }

    public static boolean isInUseBy(@Nullable class_1297 entity) {
        return entity instanceof class_1657 player && player.method_6115() && player.method_6030().method_31574(VAItems.SPECTRAL_SPYGLASS);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.method_8608()) {
            PlayerProjectionEntity.createForPlayer(user);
        }
        user.method_5783(VASoundEvents.ENTITY_SPECTRE_EMPOWER_START, 1.0F, 1.0F);
        user.method_7259(class_3468.field_15372.method_14956(this));
        user.method_5728(false);
        return class_5328.method_29282(world, user, hand);
    }

    @Override
    public boolean method_7840(class_1799 stack, class_1937 world, class_1309 user, int remainingUseTicks) {
        return super.method_7840(stack, world, user, remainingUseTicks);
    }
}

==> virtual-additions-4.0.1%2B1.21.10-sources.jar: com/github/suninvr/virtualadditions/item/ProjectionSpyglassItem.java <==
package com.github.suninvr.virtualadditions.item;

import com.github.suninvr.virtualadditions.entity.PlayerProjectionEntity;
import com.github.suninvr.virtualadditions.registry.VAItems;
import com.github.suninvr.virtualadditions.registry.VASoundEvents;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3468;
import net.minecraft.class_5328;
import net.minecraft.class_5538;
import net.minecraft.class_5712;
import org.jetbrains.annotations.Nullable;

public class ProjectionSpyglassItem extends class_5538 {
    public ProjectionSpyglassItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public int method_7881(class_1799 stack, class_1309 user) {
        return 12000;
    }

    public static boolean isInUseBy(@Nullable class_1297 entity) {
        return entity instanceof class_1657 player && player.method_6115() && player.method_6030().method_31574(VAItems.SPECTRAL_SPYGLASS);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.method_8608()) {
            PlayerProjectionEntity entity = PlayerProjectionEntity.createForPlayer(user);
            if (entity != null) world.method_43275(entity, class_5712.field_28738, entity.method_73189());
        }
        user.method_5783(VASoundEvents.ITEM_SPECTRAL_SPYGLASS_START, 1.0F, 1.0F);
        user.method_7259(class_3468.field_15372.method_14956(this));
        user.method_5728(false);
        return class_5328.method_29282(world, user, hand);
    }

    @Override
    public boolean method_7840(class_1799 stack, class_1937 world, class_1309 user, int remainingUseTicks) {
        return super.method_7840(stack, world, user, remainingUseTicks);
    }
}
